"use strict";

exports.__esModule = true;
exports.renderToHtml = renderToHtml;

var _shiki = require("shiki");

function renderToHtml(lines, options = {}) {
  const bg = options.bg || "#fff";
  let html = "";
  html += `<pre class="shiki" style="background-color: ${bg};padding: 0.75rem;border-radius: 0.25rem;position: relative;">`;

  if (options.langId) {
    html += `<div class="language-id" style="position: absolute;right: 0;top: 0;color:#eee;background-color: #393939;padding: 0.125rem 0.425rem;border-radius: 0.125rem;">${options.langId}</div>`;
  }

  html += `<code class="code">`;
  lines.forEach(l => {
    html += `<span class="line">`;
    l.forEach(token => {
      const cssDeclarations = [`color: ${token.color || options.fg}`];

      if (token.fontStyle & _shiki.FontStyle.Italic) {
        cssDeclarations.push("font-style: italic");
      }

      if (token.fontStyle & _shiki.FontStyle.Bold) {
        cssDeclarations.push("font-weight: bold");
      }

      if (token.fontStyle & _shiki.FontStyle.Underline) {
        cssDeclarations.push("text-decoration: underline");
      }

      html += `<span style="${cssDeclarations.join("; ")}">${escapeHtml(token.content)}</span>`;
    });
    html += `</span>\n`;
  });
  html = html.replace(/\n*$/, ""); // Get rid of final new lines

  html += `</code></pre>`;
  return html;
}

const htmlEscapes = {
  "&": "&amp;",
  "<": "&lt;",
  ">": "&gt;",
  '"': "&quot;",
  "'": "&#39;"
};

function escapeHtml(html) {
  return html.replace(/[&<>"']/g, chr => htmlEscapes[chr]);
}